@@ -120,8 +120,10 @@ class DockerCreateCommand(BaseELGCommand):
         self._service_type = service_type
 
     def run(self):
-        from ..flask_service import FlaskService
-        from ..quart_service import QuartService
+        if self._service_type == "flask":
+            from ..flask_service import FlaskService
+        elif self._service_type == "quart":
+            from ..quart_service import QuartService
 
         try:
             logger.info(f"Creation of `requirements.txt`")
