@@ -7,9 +7,9 @@ from tqdm import tqdm
 from .authentication import (Authentication, NeedAuthentication,
                              need_authentication)
 from .entity import Entity
-from .utils import (CORPUS_DOWNLOAD_URL, LICENCE_URL, get_domain, get_en_value,
-                    get_information, get_metadatarecord,
-                    map_metadatarecord_to_result)
+from .utils import (CORPUS_DOWNLOAD_URL, LICENCE_URL, get_argument_from_json,
+                    get_domain, get_en_value, get_information,
+                    get_metadatarecord, map_metadatarecord_to_result)
 from .utils.errors import (NotCorpusException, catch_requests_error,
                            ensure_response_ok)
 
@@ -54,6 +54,7 @@ class Distribution:
 
     def __init__(
         self,
+        pk: int,
         corpus_id: int,
         domain: str,
         form: str,
@@ -63,7 +64,9 @@ class Distribution:
         licence: Licence,
         cost: str,
         attribution_text: str,
+        filename: str,
     ):
+        self.pk = pk
         self.corpus_id = corpus_id
         self.domain = domain
         self.form = form
@@ -73,6 +76,7 @@ class Distribution:
         self.licence = licence
         self.cost = cost
         self.attribution_text = attribution_text
+        self.filename = filename
 
     @classmethod
     def from_data(cls, corpus_id: int, domain: str, data: dict):
@@ -88,6 +92,7 @@ class Distribution:
         Returns:
             elg.Distribution: the distribution object initialized.
         """
+        pk = get_information(id=-1, obj=data, infos="pk")
         form = get_information(id=-1, obj=data, infos="dataset_distribution_form")
         distribution_location = get_information(id=-1, obj=data, infos="distribution_location", none=True)
         download_location = get_information(id=-1, obj=data, infos="download_location", none=True)
@@ -104,7 +109,13 @@ class Distribution:
         attribution_text = get_information(id=-1, obj=data, infos="attribution_text", none=True)
         if attribution_text is not None:
             attribution_text = get_en_value(attribution_text)
+        dataset = get_information(id=-1, obj=data, infos="dataset", none=True)
+        if dataset is not None:
+            filename = get_information(id=-1, obj=dataset, infos="file", none=True)
+        else:
+            filename = None
         return cls(
+            pk=pk,
             corpus_id=corpus_id,
             domain=domain,
             form=form,
@@ -114,6 +125,7 @@ class Distribution:
             licence=licence,
             cost=cost,
             attribution_text=attribution_text,
+            filename=filename,
         )
 
     def is_downloadable(self) -> str:
@@ -146,6 +158,7 @@ class Distribution:
             return None
         if self.download_location is not None and self.download_location != "":
             return self.download_location
+        headers = {"Authorization": f"Bearer {access_token}"}
         elg_licence_identifier = self.licence._get_elg_licence_identifier()
         if elg_licence_identifier is not None:
             elg_licence_url = LICENCE_URL.format(domain=self.domain, licence=elg_licence_identifier)
@@ -159,11 +172,11 @@ class Distribution:
             if accept not in ["yes", "Yes", "y", "Y"]:
                 print("You need to accept the licence terms to download this corpus distribution.")
                 return None
-        data = {"licences": [f"{elg_licence_identifier}"]}
-        headers = {"Authorization": f"Bearer {access_token}"}
-        response = requests.post(
-            CORPUS_DOWNLOAD_URL.format(domain=self.domain, id=self.corpus_id), json=data, headers=headers
-        )
+            headers["accept-licence"] = "True"
+
+        headers["filename"] = str(self.filename)
+        headers["elg-resource-distribution-id"] = str(self.pk)
+        response = requests.post(CORPUS_DOWNLOAD_URL.format(domain=self.domain, id=self.corpus_id), headers=headers)
         if response.ok:
             return response.json()["s3-url"]
         print(not_downloadable)
