@@ -14,7 +14,7 @@ try:
     from requests_toolbelt import MultipartDecoder
 except:
     raise ImportError(
-        "Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[quart]`."
+        "Extra dependencies need to be install to use the QuartService class. Please run: `pip install elg[quart]`."
     )
 
 from werkzeug.exceptions import BadRequest, RequestEntityTooLarge
