@@ -274,7 +274,7 @@ class Service(Entity, NeedAuthentication):
         image_port = int(image_port) if image_port is not None else 80
         print(
             "To call the service locally, the docker image needs to be running. ",
-            f"Please run the following command: `docker run -p 127.0.0.1:{port}:{image_port} {image}`.",
+            f"Please run the following command: `docker run -p {port}:{image_port} {image}`.",
             "When calling the service, you need to set the `sync_mode` parameter to True, otherwise an error will be raised.",
         )
         auth_object = Authentication(domain="local")
